@@ -23,7 +23,7 @@ user_api_bp = Blueprint('user_api_bp', __name__,
                                  static_folder='static',
                                  url_prefix='/api/v1/users')
 
-logger = logging.getLogger('api')
+logger = logging.getLogger('debug')
 
 
 @user_api_bp.route('/register', methods=['POST'])
